==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/hotkey/translations/hotkey_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Изменить сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>Нажмите клавиши, сочетание которых вы хотите использовать</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="31"/>
        <source>Global Hotkey Plugin</source>
        <translation>Модуль глоб. клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>About Global Hotkey Plugin</source>
        <translation>О модуле глобальных клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Модуль глобальных клавиш для Qmmp</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>Этот модуль добавляет поддержку медиа- или глобальных клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>Play/Pause</source>
        <translation>Воспроиз/приост</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>Next</source>
        <translation>Следующий фрагмент</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Previous</source>
        <translation>Предыдущий фрагмент</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Show/Hide</source>
        <translation>Показать/Скрыть</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Volume +</source>
        <translation>Громкость +</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Volume -</source>
        <translation>Громкость -</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Forward 5 seconds</source>
        <translation>Вперёд на 5 секунд</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Rewind 5 seconds</source>
        <translation>Назад на 5 секунд</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Jump to track</source>
        <translation>Перейти к треку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Key sequence &apos;%1&apos; is already used</source>
        <translation>Сочитание клавиш &quot;%1&quot; уже используется</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Настройки модуля глобальных клавиш</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Горячая клавиша</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/hotkey/translations/hotkey_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Изменить сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>Нажмите клавиши, сочетание которых вы хотите использовать</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="31"/>
        <source>Global Hotkey Plugin</source>
        <translation>Модуль глоб. клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>About Global Hotkey Plugin</source>
        <translation>О модуле глобальных клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Модуль глобальных клавиш для Qmmp</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>Этот модуль добавляет поддержку медиа- или глобальных клавиш</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Настройки модуля глобальных клавиш</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Горячая клавиша</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>Play/Pause</source>
        <translation>Воспроиз/приост</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>Next</source>
        <translation>Следующий фрагмент</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Previous</source>
        <translation>Предыдущий фрагмент</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Show/Hide</source>
        <translation>Показать/Скрыть</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Volume +</source>
        <translation>Громкость +</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Volume -</source>
        <translation>Громкость -</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Forward 5 seconds</source>
        <translation>Вперёд на 5 секунд</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Rewind 5 seconds</source>
        <translation>Назад на 5 секунд</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Jump to track</source>
        <translation>Перейти к треку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Key sequence &apos;%1&apos; is already used</source>
        <translation>Сочетание клавиш &quot;%1&quot; уже используется</translation>
    </message>
</context>
</TS>
